==> connector-client-1.0.0-20230323.092234-1-sources.jar: com/daas/nros/connector/model/vo/MemberInfoQueryResponseVO.java <==
package com.daas.nros.connector.model.vo;

import com.bizvane.connectorservice.entity.base.BaseModel;
import lombok.ToString;

/**
 * @author admin
 */
@ToString
public class MemberInfoQueryResponseVO extends BaseModel {


    /**
     * 当前累计可用积分
     */
    private Integer countIntegral;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;


    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
}

==> connector-client-1.0.0-20230324.090846-5-sources.jar: com/daas/nros/connector/model/vo/MemberInfoQueryResponseVO.java <==
package com.daas.nros.connector.model.vo;

import com.daas.nros.connector.model.base.BaseModel;
import lombok.ToString;

/**
 * @author admin
 */
@ToString
public class MemberInfoQueryResponseVO extends BaseModel {


    /**
     * 当前累计可用积分
     */
    private Integer countIntegral;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;


    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
}
